@@ -101,6 +101,8 @@ const (
 	EXECUTIONTIME SegmentType = "executiontime"
 	// EXIT writes the last exit code
 	EXIT SegmentType = "exit"
+	// FLUTTER writes the flutter version
+	FLUTTER SegmentType = "flutter"
 	// GIT represents the git status and information
 	GIT SegmentType = "git"
 	// GOLANG writes which go version is currently active
@@ -127,6 +129,8 @@ const (
 	NODE SegmentType = "node"
 	// npm version
 	NPM SegmentType = "npm"
+	// NX writes which Nx version us currently active
+	NX SegmentType = "nx"
 	// OS write os specific icon
 	OS SegmentType = "os"
 	// OWM writes the weather coming from openweatherdata
@@ -159,6 +163,8 @@ const (
 	SPOTIFY SegmentType = "spotify"
 	// STRAVA is a sports activity tracker
 	STRAVA SegmentType = "strava"
+	// Subversion segment
+	SVN SegmentType = "svn"
 	// SWIFT writes the active swift version
 	SWIFT SegmentType = "swift"
 	// SYSTEMINFO writes system information (memory, cpu, load)
@@ -261,6 +267,7 @@ func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error
 		DOTNET:        &segments.Dotnet{},
 		EXECUTIONTIME: &segments.Executiontime{},
 		EXIT:          &segments.Exit{},
+		FLUTTER:       &segments.Flutter{},
 		GIT:           &segments.Git{},
 		GOLANG:        &segments.Golang{},
 		HASKELL:       &segments.Haskell{},
@@ -274,6 +281,7 @@ func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error
 		NIGHTSCOUT:    &segments.Nightscout{},
 		NODE:          &segments.Node{},
 		NPM:           &segments.Npm{},
+		NX:            &segments.Nx{},
 		OS:            &segments.Os{},
 		OWM:           &segments.Owm{},
 		PATH:          &segments.Path{},
@@ -290,6 +298,7 @@ func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error
 		SHELL:         &segments.Shell{},
 		SPOTIFY:       &segments.Spotify{},
 		STRAVA:        &segments.Strava{},
+		SVN:           &segments.Svn{},
 		SWIFT:         &segments.Swift{},
 		SYSTEMINFO:    &segments.SystemInfo{},
 		TERRAFORM:     &segments.Terraform{},
